@@ -25,14 +25,15 @@ from fanstatic import Library, Resource
 # import Zope3 packages
 
 # import local packages
+from ztfy.i18n.browser import ztfy_i18n
 from ztfy.jqueryui import jquery_alerts
-from ztfy.skin import ztfy_skin
+from ztfy.skin import ztfy_skin, ztfy_skin_base
 
 
 library = Library('ztfy.blog', 'resources')
 
 ztfy_blog_back = Resource(library, 'js/ztfy.blog.back.js', minified='js/ztfy.blog.back.min.js',
-                          depends=[ztfy_skin, jquery_alerts])
+                          depends=[ztfy_skin, ztfy_i18n, jquery_alerts], bottom=True)
 
 ztfy_blog_front = Resource(library, 'js/ztfy.blog.front.js', minified='js/ztfy.blog.front.min.js',
-                           depends=[ztfy_skin])
+                           depends=[ztfy_skin_base], bottom=True)
